#!/usr/bin/python
# -*- coding: UTF-8 -*-
import hashlib

from os.path import split, splitext, getctime, getsize, getmtime
from sys import stdout
from time import ctime
from abc import ABCMeta

VALID_VIDEO_FILE_EXTENSIONS = ['.avi', '.mov', '.mp4', '.mpeg', '.mpg', '.mkv']
VALID_AUDIO_FILE_EXTENSIONS = ['.wav', '.mp3', '.ogg']
VALID_IMAGE_FILE_EXTENSIONS = ['.bmp', '.gif', '.jpg', '.psd', '.tga', '.tif']
VALID_DOCUMENT_FILE_EXTENSIONS = ['.doc', '.docx', '.pdf', '.txt']
BUFFER = 8192

class FormatException(Exception):
    def __init__(self, value):
         self.value = value

    def __str__(self):
        return self.value


class FileMetadata(object):
    __metaclass__ = ABCMeta
    def __init__(self, sourcefile):
        self.___source = sourcefile
        self.___fileName = split(sourcefile)[1]
        self.___filePath = split(sourcefile)[0]
        self.___metadataDOM = None

    def __validateFileType(self):
        # check file extensions
        validation = True
        valid_extension = False
        file_extension = splitext(self.___source)[1]
        for extension in VALID_VIDEO_FILE_EXTENSIONS:
            if file_extension == extension:
                valid_extension = True
                break
        for extension in VALID_AUDIO_FILE_EXTENSIONS:
            if file_extension == extension:
                valid_extension = True
                break
        if not valid_extension:
            raise FormatException(file_extension + " is not an audio or video file.")
            # validation = False
        return validation



    def __sizeofHuman(self, num):
        num = int(num)
        for x in ['bytes', 'KB', 'MB', 'GB', 'TB']:
            if num < 1024.0:
                return "%3.1f %s" % (num, x)
            num /= 1024.0


    @property
    def file_name(self):
        return self.___fileName

    @property
    def file_path(self):
        return self.___filePath

    @property
    def file_extension(self):
        return str(splitext(self.___source)[1])

    @property
    def format_type(self):
        #check if it's an audio format
        for extension in VALID_AUDIO_FILE_EXTENSIONS:
            if extension in self.___source:
                return "audio"

        #check if it's a video format
        for extension in VALID_VIDEO_FILE_EXTENSIONS:
            if extension in self.___source:
                return "video"
        return "unknown"

    @property
    def file_size(self):
        return getsize(self.___source)

    @property
    def file_size_human(self):
        return self.__sizeofHuman(getsize(self.___source))

    @property
    def date_created(self):
        return ctime(getctime(self.___source))

    @property
    def date_last_modified(self):
        return ctime(getmtime(self.___source))

    def getXML(self):
        pass

    def calculate_MD5(self, verbose=False):
        md5 = hashlib.md5()
        total = self.file_size
        with open(self.___source,'rb') as f:
            i = float(0)

            for chunk in iter(lambda: f.read(BUFFER), b''):
                if verbose:
                    i += BUFFER
                    completed = int((i/total)*100)
                    print str(completed) + "%"
                md5.update(chunk)
        return md5.hexdigest()


    def calculate_SHA1(self, verbose=False):
        sha1 = hashlib.sha1()
        total = self.file_size

        with open(self.___source,'rb') as f:
            i = float(0)
            for chunk in iter(lambda: f.read(BUFFER), b''):
                if verbose:
                    i += BUFFER
                    completed = int((i/total)*100)
                    print str(completed) + "%"
                sha1.update(chunk)

        return sha1.hexdigest()

# TODO add a class for better progress reporting



#!/usr/bin/python
# -*- coding: UTF-8 -*-
from abc import ABCMeta
class CRSMetadata(object):
    __metaclass__ = ABCMeta
    def __init__(self):
        self.___crsAutoBrightness = None
        self.___crsAutoContrast = None
        self.___crsAutoExposure = None
        self.___crsAutoShadows = None
        self.___crsBlueHue = None
        self.___crsBlueSaturation = None
        self.___crsBrightness = None
        self.___crsCameraProfile = None
        self.___crsChromaticAberrationB = None
        self.___crsChromaticAberrationR = None
        self.___crsColorNoiseReduction = None
        self.___crsContrast = None
        self.___crsCropTop = None
        self.___crsCropLeft = None
        self.___crsCropRight = None
        self.___crsCropWidth = None
        self.___crsCropHeight = None
        self.___crsCropUnits = None
        self.___crsExposure = None
        self.___crsGreenHue = None
        self.___crsGreenSaturation = None
        self.___crsHasCrop = None
        self.___crsHasSetings = None
        self.___crsLuminanceSmoothing = None
        self.___crsRawFileName = None
        self.___crsRedHue = None
        self.___crsRedSaturation = None
        self.___crsSaturation = None
        self.___crsShadows = None
        self.___crsShadowTint = None
        self.___crsSharpness = None
        self.___crsTemperature = None
        self.___crsTint = None
        self.___crsToneCurve = None
        self.___crsToneCurveNae = None
        self.___crsVersion = None
        self.___crsVignetteAmount = None
        self.___crsVignetteMidpoint = None
        self.___crsWhiteBalance = None

    def getCrsAutoBrightness(self):
        return self.___crsAutoBrightness

    def getCrsAutoContrast(self):
        return self.___crsAutoContrast

    def getCrsAutoExposure(self):
        return self.___crsAutoExposure

    def getCrsAutoShadows(self):
        return self.___crsAutoShadows

    def getCrsBlueHue(self):
        return self.___crsBlueHue

    def getCrsBlueSaturation(self):
        return self.___crsBlueSaturation

    def getCrsBrightness(self):
        return self.___crsBrightness

    def getCrsCameraProfile(self):
        return self.___crsCameraProfile

    def getCrsChromaticAberrationB(self):
        return self.___crsChromaticAberrationB

    def getCrsChromaticAberrationR(self):
        return self.___crsChromaticAberrationR

    def getCrsColorNoiseReduction(self):
        return self.___crsColorNoiseReduction

    def getCrsContrast(self):
        return self.___crsContrast

    def getCrsCropTop(self):
        return self.___crsCropTop

    def getCrsCropLeft(self):
        return self.___crsCropLeft

    def getCrsCropRight(self):
        return self.___crsCropRight

    def getCrsCropWidth(self):
        return self.___crsCropWidth

    def getCrsCropHeight(self):
        return self.___crsCropHeight

    def getCrsCropUnits(self):
        return self.___crsCropUnits

    def getCrsExposure(self):
        return self.___crsExposure

    def getCrsGreenHue(self):
        return self.___crsGreenHue

    def getCrsGreenSaturation(self):
        return self.___crsGreenSaturation

    def getCrsHasCrop(self):
        return self.___crsHasCrop

    def getCrsHasSetings(self):
        return self.___crsHasSetings

    def getCrsLuminanceSmoothing(self):
        return self.___crsLuminanceSmoothing

    def getCrsRawFileName(self):
        return self.___crsRawFileName

    def getCrsRedHue(self):
        return self.___crsRedHue

    def getCrsRedSaturation(self):
        return self.___crsRedSaturation

    def getCrsSaturation(self):
        return self.___crsSaturation

    def getCrsShadows(self):
        return self.___crsShadows

    def getCrsShadowTint(self):
        return self.___crsShadowTint

    def getCrsSharpness(self):
        return self.___crsSharpness

    def getCrsTemperature(self):
        return self.___crsTemperature

    def getCrsTint(self):
        return self.___crsTint

    def getCrsToneCurve(self):
        return self.___crsToneCurve

    def getCrsToneCurveNae(self):
        return self.___crsToneCurveNae

    def getCrsVersion(self):
        return self.___crsVersion

    def getCrsVignetteAmount(self):
        return self.___crsVignetteAmount

    def getCrsVignetteMidpoint(self):
        return self.___crsVignetteMidpoint

    def getCrsWhiteBalance(self):
        return self.___crsWhiteBalance




#!/usr/bin/python
# -*- coding: UTF-8 -*-

from onesheet import DublinCoreMetadata
from onesheet.ClassFileMetadata import FileMetadata
from abc import ABCMeta
class XMPMetadata(FileMetadata, DublinCoreMetadata):
    __metaclass__ = ABCMeta
    def __init__(self):
        # TODO Make class XMPMetadata constructor
        self.___embeddedXMP = None
        self.___xmpAdvisory = None
        self.___xmpBaseURL = None
        self.___xmpCreationDate = None
        self.___xmpCreatorTool = None
        self.___xmpIdentifier = None
        self.___xmpLabel = None
        self.___xmpMetadataDate = None
        self.___xmpModifyDate = None
        self.___xmpNickname = None
        self.___xmpRating = None
        self.___xmpThumbnails = None
        self.___xmpidqScheme = None
        self.___xmpRightsCertification = None
        self.___xmpRightsMarked = None
        self.___xmpRightsOwner = None
        self.___xmpRightsUsageTerms = None
        self.___xmpRightsWebStatement = None
        self.___xmpMMDerivativedFrom = None
        self.___xmpMMDocumentID = None
        self.___xmpMMHistory = None
        self.___xmpMMInstanceID = None
        self.___xmpMMManagedFrom = None
        self.___xmpMMManager = None
        self.___xmpMMManageTo = None
        self.___xmpMMManageUI = None
        self.___xmpMMManagerVariant = None
        self.___xmpMMRenditionClass = None
        self.___xmpMMRenditionParams = None
        self.___xmpMMVersionID = None
        self.___xmpMMVersions = None
        self.___xmpMMLastURL = None
        self.___xmpMMRenditionOf = None
        self.___xmpMMSaveID = None
        self.___xmpBJJobRef = None
        self.___xmpTPgMaxPageSize = None
        self.___xmpTPgNPages = None
        self.___xmpTPgFonts = None
        self.___xmpTPgColorants = None
        self.___xmpTPgPlateNames = None
        self.___xmpDMProjectRef = None
        self.___xmpDMFileDataRate = None
        self.___xmpDMTapeName = None
        self.___xmpDMAltTapeName = None
        self.___xmpDMStartTimeCode = None
        self.___xmpDMAltTimeCode = None
        self.___xmpDMDuration = None
        self.___xmpDMScene = None
        self.___xmpDMShotName = None
        self.___xmpDMShotDate = None
        self.___xmpDMShotLocation = None
        self.___xmpDMLogComment = None
        self.___xmpDMMarkers = None
        self.___xmpDMContributedMedia = None
        self.___xmpDMMetadataModDate = None

    def embededXMPMetadata(self):
        pass

    def getXMPAdvisory(self):
        pass

    def getXMPBaseURL(self):
        pass

    def getXMPCreationDate(self):
        pass

    def getXMPCreatorTool(self):
        pass

    def getXMPIndentifier(self):
        pass

    def getXMPLabel(self):
        pass

    def getXMPMetadataDate(self):
        pass

    def getXMPModifyDate(self):
        pass

    def getXMPNickname(self):
        pass

    def getXMPRating(self):
        pass

    def getXMPThumnails(self):
        pass

    def getXMPidqScheme(self):
        return self.___xmpidqScheme

    def getXMPRightsCertification(self):
        return self.___xmpRightsCertification

    def getXMPRightsMarked(self):
        return self.___xmpRightsMarked

    def getXMPRightsOwner(self):
        return self.___xmpRightsOwner

    def getXMPRightsUsageTerms(self):
        return self.___xmpRightsUsageTerms

    def getXMPRightsWebStatement(self):
        return self.___xmpRightsWebStatement

    def getXMPMMDerivativedFrom(self):
        return self.___xmpMMDerivativedFrom

    def getXMPMMDocumentID(self):
        return self.___xmpMMDocumentID

    def getXMPMMHistory(self):
        return self.___xmpMMHistory

    def getXMPMMInstanceID(self):
        return self.___xmpMMInstanceID

    def getXMPMMManagedFrom(self):
        return self.___xmpMMManagedFrom

    def getXMPMMManager(self):
        return self.___xmpMMManager

    def getXMPMMManageTo(self):
        return self.___xmpMMManageTo

    def getXMPMMManageUI(self):
        return self.___xmpMMManageUI

    def getXMPMMManagerVariant(self):
        return self.___xmpMMManagerVariant

    def getXMPMMRenditionClass(self):
        return self.___xmpMMRenditionClass

    def getXMPMMRenditionParams(self):
        return self.___xmpMMRenditionParams

    def getXMPMMVersionID(self):
        return self.___xmpMMVersionID

    def getXMPMMVersions(self):
        return self.___xmpMMVersions

    def getXMPMMLastURL(self):
        return self.___xmpMMLastURL

    def getXMPMMRenditionOf(self):
        return self.___xmpMMRenditionOf

    def getXMPMMSaveID(self):
        return self.___xmpMMSaveID

    def getXMPBJJobRef(self):
        return self.___xmpBJJobRef

    def getXMPTPgMaxPageSize(self):
        return self.___xmpTPgMaxPageSize

    def getXMPTPgNPages(self):
        return self.___xmpTPgNPages

    def getXMPTPgFonts(self):
        return self.___xmpTPgFonts

    def getXMPTPgColorants(self):
        return self.___xmpTPgColorants

    def getXMPTPgPlateNames(self):
        return self.___xmpTPgPlateNames

    def getXMPDMProjectRef(self):
        return self.___xmpDMProjectRef

    def getXMPDMFileDataRate(self):
        return self.___xmpDMFileDataRate

    def getXMPDMTapeName(self):
        return self.___xmpDMTapeName

    def getXMPDMAltTapeName(self):
        return self.___xmpDMAltTapeName

    def getXMPDMStartTimeCode(self):
        return self.___xmpDMStartTimeCode

    def getXMPDMAltTimeCode(self):
        return self.___xmpDMAltTimeCode

    def getXMPDMDuration(self):
        return self.___xmpDMDuration

    def getXMPDMScene(self):
        return self.___xmpDMScene

    def getXMPDMShotName(self):
        return self.___xmpDMShotName

    def getXMPDMShotDate(self):
        return self.___xmpDMShotDate

    def getXMPDMShotLocation(self):
        return self.___xmpDMShotLocation

    def getXMPDMLogComment(self):
        return self.___xmpDMLogComment

    def getXMPDMMarkers(self):
        return self.___xmpDMMarkers

    def getXMPDMContributedMedia(self):
        return self.___xmpDMContributedMedia

    def getXMPDMMetadataModDate(self):
        return self.___xmpDMMetadataModDate

